from setuptools import setup

setup(
    name='django-mango',
    version='0.0.1',
    description='A momentary assessment app for Django',
    long_description='Mango is a reusable Django app that provides an SMS ecological momentary assessment framework through Twilio.',
    url='https://github.com/DynamicGenetics/Mango',
    author='Nina Di Cara, Valerio Maggio',
    author_email='nina.dicara@bristol.ac.uk',
    packages=[],
    classifiers=['Development Status :: 1 - Planning'],
)